==> kadai-common-data-9.1.0.jar: sql/sample-data/user.sql <==
-- sample-data is used for rest tests and for the example application

-- USER_INFO TABLE          (USER_ID          , FIRST_NAME , LASTNAME      , FULL_NAME          , LONG_NAME                            , E_MAIL                    , PHONE         , MOBILE_PHONE      , ORG_LEVEL_4   , ORG_LEVEL_3   , ORG_LEVEL_2        , ORG_LEVEL_1   , DATA
insert into USER_INFO values('teamlead-1'     , 'Titus'    , 'Toll'        , 'Toll, Titus'      , 'Toll, Titus - (teamlead-1)'         , 'titus.toll@web.de'       , '040-2951854' , '015637683197'    , 'Envite'     , 'BPM'         , 'Human Workflow'   , 'KADAI'     , 'xy'  );
insert into USER_INFO values('user-1-1'       , 'Max'      , 'Mustermann'  , 'Mustermann, Max'  , 'Mustermann, Max - (user-1-1)'       , 'max.mustermann@web.de'   , '040-2951854' , '015637683197'    , 'Envite'     , 'BPM'         , 'Human Workflow'   , 'KADAI'     , ''    );
insert into USER_INFO values('user-1-2'       , 'Elena'    , 'Eifrig'      , 'Eifrig, Elena'    , 'Eifrig, Elena - (user-1-2)'         , 'elena.eifrig@web.de'     , '040-2951854' , '015637683197'    , 'Envite'     , 'BPM'         , 'Human Workflow'   , 'KADAI'     , ''    );
insert into USER_INFO values('user-1-3'       , 'Elena'    , 'Faul'        , 'Faul, Elena'      , 'Faul, Elena - (user-1-3)'           , 'elena.faul@web.de'       , '040-2951854' , '015637683197'    , 'Envite'     , 'BPM'         , 'Human Workflow'   , 'KADAI'     , ''    );
insert into USER_INFO values('user-2-1'       , 'Simone'   , 'Müller'      , 'Müller, Simone'   , 'Müller, Simone - (user-2-1)'        , 'simone.müller@web.de'    , '040-2951854' , '015637683197'    , 'Envite'     , 'BPM'         , 'Human Workflow'   , 'KADAI'     , ''    );
insert into USER_INFO values('user-2-2'       , 'Tim'      , 'Schläfrig'   , 'Schläfrig, Tim'   , 'Schläfrig, Tim - (user-2-2)'        , 'tim.schläfrig@web.de'    , '040-2951854' , '015637683197'    , 'Envite'     , 'BPM'         , 'Human Workflow'   , 'KADAI'     , ''    );
insert into USER_INFO values('user-2-3'       , 'Thomas'   , 'Bach'        , 'Bach, Thomas'     , 'Bach, Thomas - (user-2-3)'          , 'thomas.bach@web.de'      , '040-2951854' , '015637683197'    , 'Envite'     , 'BPM'         , 'Human Workflow'   , 'KADAI'     , ''    );
insert into USER_INFO values('user-2-4'       , 'Rolf'     , 'Wieland'     , 'Wieland, Rolf'    , 'Wieland, Rolf - (user-2-4)'         , 'rolf.wieland@web.de'     , '040-2951854' , '015637683197'    , 'Envite'     , 'BPM'         , 'Human Workflow'   , 'KADAI'     , ''    );
insert into USER_INFO values('user-2-5'       , 'Heike'    , 'Schmidt'     , 'Schmidt, Heike'   , 'Schmidt, Heike - (user-2-5)'        , 'heike.schmidt@web.de'    , '040-2951854' , '015637683197'    , 'Envite'     , 'BPM'         , 'Human Workflow'   , 'KADAI'     , ''    );
insert into USER_INFO values('user-2-6'       , 'Kurt'     , 'Maier'       , 'Maier, Kurt'      , 'Maier, Kurt - (user-2-6)'           , 'kurt.maier@web.de'       , '040-2951854' , '015637683197'    , 'Envite'     , 'BPM'         , 'Human Workflow'   , 'KADAI'     , ''    );
insert into USER_INFO values('user-2-7'       , 'Wiebke'   , 'Meyer'       , 'Meyer, Wiebke'    , 'Meyer, Wiebke - (user-2-7)'         , 'wiebke.meyer@web.de'     , '040-2951854' , '015637683197'    , 'Envite'     , 'BPM'         , 'Human Workflow'   , 'KADAI'     , ''    );
insert into USER_INFO values('user-2-9'       , 'Nathalie' , 'Fuchs'       , 'Fuchs, Nathalie'  , 'Fuchs, Nathalie - (user-2-9)'       , 'nathalie.fuchs@web.de'   , '040-2951854' , '015637683197'    , 'Envite'     , 'BPM'         , 'Human Workflow'   , 'KADAI'     , ''    );
insert into USER_INFO values('user-2-10'      , 'Johannes' , 'Renz'        , 'Renz, Johannes'   , 'Renz, Johannes - (user-2-10)'       , 'johannes.renz@web.de'    , '040-2951854' , '015637683197'    , 'Envite'     , 'BPM'         , 'Human Workflow'   , 'KADAI'     , ''    );
insert into USER_INFO values('user-2-11'      , 'Max'      , 'Renz'        , 'Renz, Max'        , 'Renz, Max - (user-2-11)'            , 'max.renz@web.de'         , '040-2951854' , '015637683197'    , 'Envite'     , 'BPM'         , 'Human Workflow'   , 'KADAI'     , ''    );

==> kadai-common-data-9.3.0.jar: sql/sample-data/user.sql <==
-- sample-data is used for rest tests and for the example application

-- USER_INFO TABLE          (USER_ID          , FIRST_NAME , LASTNAME      , FULL_NAME          , LONG_NAME                            , E_MAIL                    , PHONE         , MOBILE_PHONE      , ORG_LEVEL_4   , ORG_LEVEL_3   , ORG_LEVEL_2        , ORG_LEVEL_1   , DATA
insert into USER_INFO values('teamlead-1'     , 'Titus'    , 'Toll'        , 'Toll, Titus'      , 'Toll, Titus - (teamlead-1)'         , 'titus.toll@web.de'       , '040-2951854' , '015637683197'    , 'Envite'     , 'BPM'         , 'Human Workflow'   , 'KADAI'     , 'xy'  );
insert into USER_INFO values('user-1-1'       , 'Max'      , 'Mustermann'  , 'Mustermann, Max'  , 'Mustermann, Max - (user-1-1)'       , 'max.mustermann@web.de'   , '040-2951854' , '015637683197'    , 'Envite'     , 'BPM'         , 'Human Workflow'   , 'KADAI'     , ''    );
insert into USER_INFO values('user-1-2'       , 'Elena'    , 'Eifrig'      , 'Eifrig, Elena'    , 'Eifrig, Elena - (user-1-2)'         , 'elena.eifrig@web.de'     , '040-2951854' , '015637683197'    , 'Envite'     , 'BPM'         , 'Human Workflow'   , 'KADAI'     , ''    );
insert into USER_INFO values('user-1-3'       , 'Elena'    , 'Faul'        , 'Faul, Elena'      , 'Faul, Elena - (user-1-3)'           , 'elena.faul@web.de'       , '040-2951854' , '015637683197'    , 'Envite'     , 'BPM'         , 'Human Workflow'   , 'KADAI'     , ''    );
insert into USER_INFO values('user-2-1'       , 'Simone'   , 'Müller'      , 'Müller, Simone'   , 'Müller, Simone - (user-2-1)'        , 'simone.müller@web.de'    , '040-2951854' , '015637683197'    , 'Envite'     , 'BPM'         , 'Human Workflow'   , 'KADAI'     , ''    );
insert into USER_INFO values('user-2-2'       , 'Tim'      , 'Schläfrig'   , 'Schläfrig, Tim'   , 'Schläfrig, Tim - (user-2-2)'        , 'tim.schläfrig@web.de'    , '040-2951854' , '015637683197'    , 'Envite'     , 'BPM'         , 'Human Workflow'   , 'KADAI'     , ''    );
insert into USER_INFO values('user-2-3'       , 'Thomas'   , 'Bach'        , 'Bach, Thomas'     , 'Bach, Thomas - (user-2-3)'          , 'thomas.bach@web.de'      , '040-2951854' , '015637683197'    , 'Envite'     , 'BPM'         , 'Human Workflow'   , 'KADAI'     , ''    );
insert into USER_INFO values('user-2-4'       , 'Rolf'     , 'Wieland'     , 'Wieland, Rolf'    , 'Wieland, Rolf - (user-2-4)'         , 'rolf.wieland@web.de'     , '040-2951854' , '015637683197'    , 'Envite'     , 'BPM'         , 'Human Workflow'   , 'KADAI'     , ''    );
insert into USER_INFO values('user-2-5'       , 'Heike'    , 'Schmidt'     , 'Schmidt, Heike'   , 'Schmidt, Heike - (user-2-5)'        , 'heike.schmidt@web.de'    , '040-2951854' , '015637683197'    , 'Envite'     , 'BPM'         , 'Human Workflow'   , 'KADAI'     , ''    );
insert into USER_INFO values('user-2-6'       , 'Kurt'     , 'Maier'       , 'Maier, Kurt'      , 'Maier, Kurt - (user-2-6)'           , 'kurt.maier@web.de'       , '040-2951854' , '015637683197'    , 'Envite'     , 'BPM'         , 'Human Workflow'   , 'KADAI'     , ''    );
insert into USER_INFO values('user-2-7'       , 'Wiebke'   , 'Meyer'       , 'Meyer, Wiebke'    , 'Meyer, Wiebke - (user-2-7)'         , 'wiebke.meyer@web.de'     , '040-2951854' , '015637683197'    , 'Envite'     , 'BPM'         , 'Human Workflow'   , 'KADAI'     , ''    );
insert into USER_INFO values('user-2-9'       , 'Nathalie' , 'Fuchs'       , 'Fuchs, Nathalie'  , 'Fuchs, Nathalie - (user-2-9)'       , 'nathalie.fuchs@web.de'   , '040-2951854' , '015637683197'    , 'Foo'        , 'Bar'         , 'Baz'              , 'Bat'       , ''    );
insert into USER_INFO values('user-2-10'      , 'Johannes' , 'Renz'        , 'Renz, Johannes'   , 'Renz, Johannes - (user-2-10)'       , 'johannes.renz@web.de'    , '040-2951854' , '015637683197'    , 'Envite'     , 'BPM'         , 'Human Workflow'   , 'KADAI'     , ''    );
insert into USER_INFO values('user-2-11'      , 'Max'      , 'Renz'        , 'Renz, Max'        , 'Renz, Max - (user-2-11)'            , 'max.renz@web.de'         , '040-2951854' , '015637683197'    , 'Envite'     , 'BPM'         , 'Human Workflow'   , 'KADAI'     , ''    );
